@@ -11,6 +11,8 @@ CURRENCY_WORD_MAPPING = {
 INVALID_CHARS = {"en": r"[^a-zA-Z]", "de": r"[^a-zA-ZäöüÄÖÜß]"}
 
 PERCENT_WORD = {"en": "percent", "de": "Prozent"}
+AND_WORD = {"en": "and", "de": "und"}
+
 
 YEAR_PRECEEDING_WORDS = {
     "en": ["in", "year", "before", "after", "since"],
@@ -94,7 +96,7 @@ class TextFormatter(BaseFormatter):
             if c == "’":
                 c = "'"
 
-            if c == "%":
+            if c == "%" or c == "&":
                 is_valid = True
             elif (
                 c == "'"
@@ -175,6 +177,9 @@ class TextFormatter(BaseFormatter):
                     else:
                         newword = self.remove_invalid_chars(newword)
                         to_append = [newword, PERCENT_WORD.get(self.lang)]
+                elif "&" in word:
+                    newword = word.replace("&", f" {AND_WORD.get(self.lang)} ")
+                    to_append = newword.strip().split()
                 elif "-" in word:
                     newword = word.replace("-", " ")
                     to_append = newword.split()
